pub struct Error(/* private fields */);Expand description
An error communicating with the Postgres server.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn into_source(self) -> Option<Box<dyn Error + Sync + Send>>
pub fn into_source(self) -> Option<Box<dyn Error + Sync + Send>>
Consumes the error, returning its cause.
Sourcepub fn as_db_error(&self) -> Option<&DbError>
pub fn as_db_error(&self) -> Option<&DbError>
Returns the source of this error if it was a DbError.
This is a simple convenience method.
Sourcepub fn code(&self) -> Option<&SqlState>
pub fn code(&self) -> Option<&SqlState>
Returns the SQLSTATE error code associated with the error.
This is a convenience method that downcasts the cause to a DbError and returns its code.
Sourcepub fn unexpected_message() -> Error
pub fn unexpected_message() -> Error
Constructs an UnexpectedMessage error.