Struct tokio_postgres::stmt::Statement [] [src]

pub struct Statement { /* fields omitted */ }

A prepared statement.

Methods

impl Statement
[src]

[src]

Returns the types of query parameters for this statement.

[src]

Returns information about the resulting columns for this statement.